==> haskell-heaps-0.3.6-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: heaps
version: 0.3.6
id: heaps-0.3.6-KB4BxB1rAgS5l6Xv3lb1eE
key: heaps-0.3.6-KB4BxB1rAgS5l6Xv3lb1eE
license: BSD-3-Clause
copyright: (c) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/heaps/
synopsis: Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.
category: Data Structures
abi: cf56a8526450c279de37e672115ab42d
exposed: True
exposed-modules:
    Data.Heap
import-dirs: /usr/lib/ghc-8.6.1/site-local/heaps-0.3.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/heaps-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/heaps-0.3.6
hs-libraries: HSheaps-0.3.6-KB4BxB1rAgS5l6Xv3lb1eE
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html: /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heaps-0.3.6-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: heaps
version: 0.3.6
id: heaps-0.3.6-LTQlqhRCQIfC1ZWdvI53xo
key: heaps-0.3.6-LTQlqhRCQIfC1ZWdvI53xo
license: BSD-3-Clause
copyright: (c) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/heaps/
synopsis: Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.
category: Data Structures
abi: c33b1be2e3bb8aaf4e047b08d85a06ba
exposed: True
exposed-modules:
    Data.Heap
import-dirs: /usr/lib/ghc-8.6.2/site-local/heaps-0.3.6
library-dirs: /usr/lib/ghc-8.6.2/site-local/heaps-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/heaps-0.3.6
hs-libraries: HSheaps-0.3.6-LTQlqhRCQIfC1ZWdvI53xo
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html: /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
